==> vee_2.4-5.tar.gz: vee-2.4/src/func.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import sys, sre, os, urllib
import gtk
import Conf

def get_vee_id (VEE_IDS) :
	b = VEE_IDS.keys()

	if len(b) < 1 : return 0

	b.sort()

	return int(b.pop()) + 1

def is_valid_command (command) :
	if command.count(os.sep) > 0 :
		if not os.path.exists(command) :
			return False
		else :
			return True

	else :
		_i, _o, _e = os.popen3("/usr/bin/which %s" % command)

		if len(_o.readlines()) < 1 :
			return False
		else :
			return True

def escape_path (path) :
	return path.replace( \
		" ", "\\ ").replace( \
		"#", "\\#").replace( \
		"(", "\\(").replace( \
		")", "\\)")

def get_filename_from_uri (uri) :
	"""
	get the unix file path from uri
	"""

	__a = uri.split(":")
	if len(__a) < 2 : return uri

	slash = sre.compile("^//")
	__b = urllib.url2pathname(slash.sub("", __a[1])).strip()

	return __b

def parse_command_line_argument (command) :
	parsed_data = { \
		"environment" : tuple(),
		"command" : str(),
		"argument" : tuple(),
	}

	__a = command.split()

	if len(__a) < 2 :
		parsed_data["command"] = command.strip()
		return parsed_data

	q = sre.compile("[A-Z][A-Z_][A-Z_]*=.*") # env

	__env = list()
	__index_env = list()
	for i in range(len(__a)) :
		if q.findall(__a[i]) :
			__env.append(__a[i].strip())
			__index_env.append(i)
		else :
			break

	parsed_data["environment"] = tuple(__env)

	if len(__index_env) > 0 :
		__index = __index_env[-1]
	else :
		__index = -1

	try :
		__command = __a[__index + 1]
	except IndexError :
		return parsed_data

	parsed_data["command"] = __command

	try :
		__argv = __a[__index + 2:]
	except IndexError :
		return parsed_data

	parsed_data["argument"] = tuple(__argv)

	return parsed_data

def normalize_path (path) :
	return path.replace("~", os.getenv("HOME"))

def get_labelname (label_name, size=10) :
	if label_name.count(os.sep) < 1 and size is not None:
		try :
			return label_name[-size]
		except IndexError :
			return label_name
	else :
		__filename = os.path.basename(label_name)
		__pathname = os.path.dirname(label_name)

		if len(__filename) >= size or size is None :
			return __filename
		else :
			__a = __pathname[-(size - len(__filename)):]

			return os.path.join(__a, __filename)

def color_to_str (gdkColor) :
	if not isinstance(gdkColor, gtk.gdk.Color) :
		raise ValueError, \
			_("gdkColor must be the instance of gtk.gdk.Color.")

	color = "#%2X%2X%2X" % ( \
		gdkColor.red / 256, \
		gdkColor.green / 256, \
		gdkColor.blue / 256, \
	)

	return color.replace(" ", "0")

def str_to_color (color_spec, default="white") :
	try :
		return gtk.gdk.color_parse(color_spec)
	except ValueError :
		return gtk.gdk.color_parse(default)
	except TypeError :
		return None

def get_list_of_vee () :
	a, b, c = os.popen3("ps aux | grep python | grep vee | grep -v grep | awk '{print $2}'")

	return [i.strip() for i in b.readlines()]

def is_valid_pid (pid) :
	if sys.platform == "linux2" :
		__directory_pid = "/proc/%d" % pid
		if not os.path.isdir(__directory_pid) :
			return False
		else :
			return True
	else :
		return True

def create_icon (icon_file_path, w=30, h=30) :
	"""
	@return pixbuf image.
	"""
	if not os.path.isfile(icon_file_path) :
		return None

	__i = gtk.Image()
	__i.set_from_file(icon_file_path)
	__i.set_property("icon-size", 0)

	__image = __i.get_pixbuf().scale_simple(w, h, 2)

	return __image

def parse_geometry (geom) :
	if geom.count("x") == 0 :
		w, h = None, None
	else :
		__wh = sre.compile("[1-9][0-9]*x[1-9][0-9]*").findall(geom)

		try :
			w, h = __wh[0].split("x")
		except IndexError :
			return None
		else :
			w, h = (int(w), int(h),)

	if geom.count("+") == 0 :
		x, y = None, None
	else :
		__xy = sre.compile("\+[1-9][0-9]*\+[1-9][0-9]*").findall(geom)

		try :
			x, y = __xy[0].replace("+", " ").split()
		except IndexError :
			return None
		else :
			x, y = (int(x), int(y),)

	return (w, h, x, y)

def get_parent_directory (path) :
	if not os.path.isdir(path) : return None

	return os.path.abspath(os.path.join(path, os.pardir))

def get_parent_directories (path) :
	__path = get_parent_directory(path)
	return get_subdirectories(__path)

def has_parent_directory (path) :
	if not os.path.isdir(path) : return False

	if len(get_parent_directories(path)) < 1 : return False
	else : return True

def get_subdirectories (path) :
	try :
		return filter(lambda i : os.path.isdir(i), \
			[ os.path.join(path, i)  for i in os.listdir(path) ])
	except OSError :
		return list()

def has_subdirectory (path) :
	if not os.path.isdir(path) : return False

	if len(get_subdirectories(path)) < 1 : return False
	else : return True

def get_pid_by_process_name (name) :
	cmd = "COLUMNS=10000 ps aux | grep \"%s\" | grep -v grep | awk '{print $2}'" % name

	i, o, e = os.popen3(cmd)
	__a = o.readlines()

	if len(__a) != 1 : return None

	try :
		__pid = int(__a[0].strip())
	except ValueError :
		return None

	return __pid

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "func.py"

==> vee_2.5-1.tar.gz: vee-2.5/src/func.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import sys, sre, os, urllib, xmlrpclib
import gtk
import Conf

def get_vee_id (VEE_IDS) :
	b = VEE_IDS.keys()

	if len(b) < 1 : return 0

	b.sort()

	return int(b.pop()) + 1

def is_valid_command (command) :
	if command.count(os.sep) > 0 :
		if not os.path.exists(command) :
			return False
		else :
			return True

	else :
		_i, _o, _e = os.popen3("/usr/bin/which %s" % command)

		if len(_o.readlines()) < 1 :
			return False
		else :
			return True

def escape_path (path) :
	return path.replace( \
		" ", "\\ ").replace( \
		"#", "\\#").replace( \
		"%", "\\%").replace( \
		"(", "\\(").replace( \
		")", "\\)")

def get_filename_from_uri (uri) :
	"""
	get the unix file path from uri
	"""

	__a = uri.split(":")
	if len(__a) < 2 : return uri

	slash = sre.compile("^//")
	__b = urllib.url2pathname(slash.sub("", __a[1])).strip()

	return __b

def parse_command_line_argument (command) :
	parsed_data = { \
		"environment" : tuple(),
		"command" : str(),
		"argument" : tuple(),
	}

	__a = command.split()

	if len(__a) < 2 :
		parsed_data["command"] = command.strip()
		return parsed_data

	q = sre.compile("[A-Z][A-Z_][A-Z_]*=.*") # env

	__env = list()
	__index_env = list()
	for i in range(len(__a)) :
		if q.findall(__a[i]) :
			__env.append(__a[i].strip())
			__index_env.append(i)
		else :
			break

	parsed_data["environment"] = tuple(__env)

	if len(__index_env) > 0 :
		__index = __index_env[-1]
	else :
		__index = -1

	try :
		__command = __a[__index + 1]
	except IndexError :
		return parsed_data

	parsed_data["command"] = __command

	try :
		__argv = __a[__index + 2:]
	except IndexError :
		return parsed_data

	parsed_data["argument"] = tuple(__argv)

	return parsed_data

def normalize_path (path) :
	return path.replace("~", os.getenv("HOME"))

def get_labelname (label_name, size=10) :
	if label_name.count(os.sep) < 1 and size is not None:
		try :
			return label_name[-size]
		except IndexError :
			return label_name
	else :
		__filename = os.path.basename(label_name)
		__pathname = os.path.dirname(label_name)

		if len(__filename) >= size or size is None :
			return __filename
		else :
			__a = __pathname[-(size - len(__filename)):]

			return os.path.join(__a, __filename)

def color_to_str (gdkColor) :
	if not isinstance(gdkColor, gtk.gdk.Color) :
		raise ValueError, \
			_("gdkColor must be the instance of gtk.gdk.Color.")

	color = "#%2X%2X%2X" % ( \
		gdkColor.red / 256, \
		gdkColor.green / 256, \
		gdkColor.blue / 256, \
	)

	return color.replace(" ", "0")

def str_to_color (color_spec, default="white") :
	try :
		return gtk.gdk.color_parse(color_spec)
	except ValueError :
		return gtk.gdk.color_parse(default)
	except TypeError :
		return None

def get_list_of_vee () :
	a, b, c = os.popen3("ps aux | grep python | grep vee | grep -v grep | awk '{print $2}'")

	return [i.strip() for i in b.readlines()]

def is_valid_pid (pid) :
	if sys.platform == "linux2" :
		__directory_pid = "/proc/%d" % pid
		if not os.path.isdir(__directory_pid) :
			return False
		else :
			return True
	else :
		return True

def create_icon (icon_file_path, w=30, h=30) :
	"""
	@return pixbuf image.
	"""
	if not os.path.isfile(icon_file_path) :
		return None

	__i = gtk.Image()
	__i.set_from_file(icon_file_path)
	__i.set_property("icon-size", 0)

	__image = __i.get_pixbuf().scale_simple(w, h, 2)

	return __image

def parse_geometry (geom) :
	if geom.count("x") == 0 :
		w, h = None, None
	else :
		__wh = sre.compile("[1-9][0-9]*x[1-9][0-9]*").findall(geom)

		try :
			w, h = __wh[0].split("x")
		except IndexError :
			return None
		else :
			w, h = (int(w), int(h),)

	if geom.count("+") == 0 :
		x, y = None, None
	else :
		__xy = sre.compile("\+[1-9][0-9]*\+[1-9][0-9]*").findall(geom)

		try :
			x, y = __xy[0].replace("+", " ").split()
		except IndexError :
			return None
		else :
			x, y = (int(x), int(y),)

	return (w, h, x, y)

def get_parent_directory (path) :
	if not os.path.isdir(path) : return None

	return os.path.abspath(os.path.join(path, os.pardir))

def get_parent_directories (path) :
	__path = get_parent_directory(path)
	return get_subdirectories(__path)

def has_parent_directory (path) :
	if not os.path.isdir(path) : return False

	if len(get_parent_directories(path)) < 1 : return False
	else : return True

def get_subdirectories (path) :
	try :
		return filter(lambda i : os.path.isdir(i), \
			[ os.path.join(path, i)  for i in os.listdir(path) ])
	except OSError :
		return list()

def has_subdirectory (path) :
	if not os.path.isdir(path) : return False

	if len(get_subdirectories(path)) < 1 : return False
	else : return True

def get_pid_by_process_name (name) :
	cmd = "COLUMNS=10000 ps aux | grep \"%s\" | grep -v grep | awk '{print $2}'" % name

	i, o, e = os.popen3(cmd)
	__a = o.readlines()

	if len(__a) != 1 : return None

	try :
		__pid = int(__a[0].strip())
	except ValueError :
		return None

	return __pid

def parse_argument_of_veet (data) :
	__a = xmlrpclib.loads(data)

	if len(__a[0]) < 2 :
		__uid = None
	else :
		__uid = __a[0][1]

	__data = __a[0][0][1:]

	return (__uid, __data)

def casting (type, value) :

	if type == "str" :
		return str("%s" % value)
	elif type == "int" :
		if not value :
			return int()
		else :
			value = str(value)
			return int(value.split(".")[:1][0])
	elif type == "float" :
		if not value :
			return float()
		else :
			return float("%s" % value)
	elif type == "bool" :
		return bool(value)
	else :
		return value

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "func.py"
